Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(965)

Unified Diff: third_party/WebKit/Source/core/events/PointerEventFactory.h

Issue 1800143002: Notify Blink about start of gesture scroll through a queued event. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed touch_event_stream_validator Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/events/PointerEventFactory.h
diff --git a/third_party/WebKit/Source/core/events/PointerEventFactory.h b/third_party/WebKit/Source/core/events/PointerEventFactory.h
index 26f304298492ef590bd524ddfa0dac03437c94b6..919b4993bcb60b8b3d721026e629041cbaf54ff4 100644
--- a/third_party/WebKit/Source/core/events/PointerEventFactory.h
+++ b/third_party/WebKit/Source/core/events/PointerEventFactory.h
@@ -40,7 +40,7 @@ public:
const double clientX, const double clientY);
PassRefPtrWillBeRawPtr<PointerEvent> createPointerCancelEvent(
- const PlatformTouchPoint&);
+ const int pointerId, const WebPointerProperties::PointerType);
// For creating capture events (i.e got/lostpointercapture)
PassRefPtrWillBeRawPtr<PointerEvent> createPointerCaptureEvent(
@@ -56,11 +56,13 @@ public:
// Clear all the existing ids.
void clear();
- // Returns true if pointerEvent is removed. When a pointerEvent with a
- // particular id is removed that id is considered free even though there
- // might have been other PointerEvents that were generated with the same id
- // before.
- bool remove(const PassRefPtrWillBeRawPtr<PointerEvent>);
+ // When a particular pointerId is removed, the id is considered free even
+ // though there might have been other PointerEvents that were generated with
+ // the same id before.
+ bool remove(const int);
+
+ // Returns all ids of the given pointerType.
+ WillBeHeapVector<int> getPointerIdsOfType(WebPointerProperties::PointerType);
tdresser 2016/04/01 14:50:24 We don't need WillBe types anymore, do we? Might a
mustaq 2016/04/01 18:31:05 Yes, good catch. Let's save one search-replace fro
// Returns whether a pointer id exists and active
bool isActive(const int);
@@ -89,8 +91,9 @@ private:
int addIdAndActiveButtons(const IncomingId, bool isActiveButtons);
bool isPrimary(const int) const;
- void setIdTypeButtons(PointerEventInit &, const WebPointerProperties &,
+ void setIdTypeButtons(PointerEventInit&, const WebPointerProperties&,
unsigned buttons);
+ void setBubblesAndCancelable(PointerEventInit&, const AtomicString& type);
static const int s_invalidId;
static const int s_mouseId;

Powered by Google App Engine
This is Rietveld 408576698